color-temp
======================

.. image:: https://badge.fury.io/py/color-temp.png
    :target: https://badge.fury.io/py/color-temp

.. image:: https://travis-ci.org/narfman0/color-temp.png?branch=master
    :target: https://travis-ci.org/narfman0/color-temp

Convert color from RGB to Kelvin and back

Usage
-----

Install with::

    pip install color_temp

And use with::

    from color_temp import rgb_to_temperature
    rgb = rgb_to_temperature(3500)

License
-------

Copyright (c) 2017 Jon Robison

See included LICENSE for licensing information
